stravalib.util.limiter.RequestRate
==================================

.. currentmodule:: stravalib.util.limiter

.. autoclass:: RequestRate


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~RequestRate.__init__
      ~RequestRate.count
      ~RequestRate.index





   .. rubric:: Attributes

   .. autosummary::

      ~RequestRate.long_limit
      ~RequestRate.long_usage
      ~RequestRate.short_limit
      ~RequestRate.short_usage
